Examples
========

.. toctree::
    :maxdepth: 2

    examples/example01_1d_kernel_introduction
    examples/example_02_1d_kernel_estimation_mle
    examples/example_03_1d_kernel_estimation_mcmc
    examples/example_04_1d_kernel_multplication_estimation_mcmc
    examples/example_05_2d_kernel_estimation_mcmc
